# coding=utf-8
import time
import unittest

from alas_ce0.management.role import RoleClient

from alas_ce0.management.feature import FeatureClient

from alas_ce0.management.resource import ResourceClient

from alas_ce0.management.roles_group import RolesGroupClient
from config import API_ACCESS_CONFIG


class TestRoleApi(unittest.TestCase):
    def test_crud(self):
        # Tests Setup

        resource_client = ResourceClient(**API_ACCESS_CONFIG)
        resource = {
            'description': 'TestResource',
            'target': '/target'
        }

        result = resource_client.create(resource)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)
        resource_id = result.content['resource_id']

        feature_client = FeatureClient(**API_ACCESS_CONFIG)
        feature = {
            'name': 'TestFeature',
            'description': 'TestFeature',
            'resources': [resource_id]
        }

        result = feature_client.create(feature)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        role_client = RoleClient(**API_ACCESS_CONFIG)
        role = {
            'name': 'TestRole',
            'description': 'TestRole',
            'features': ["TestFeature"]
        }

        result = role_client.create(role)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        # RolesGroup Tests

        roles_group_client = RolesGroupClient(**API_ACCESS_CONFIG)
        roles_group = {
            'name': 'TestRolesGroup',
            'description': 'TestRolesGrou',
            'roles': ["TestRole"]
        }

        result = roles_group_client.create(roles_group)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        result = roles_group_client.get_by_id(result.content['name'])
        self.assertTrue(result.response.status == 200 and result.content)

        result = roles_group_client.get_by_id('sample-roles-group')
        self.assertTrue(result.response.status == 404)

        result = roles_group_client.search({'description': 'TestRolesGrou'})
        self.assertTrue(result.response.status == 200 and result.content)

        result = roles_group_client.delete(result.content['items'][0]['name'])
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)

        result = roles_group_client.create(roles_group)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        roles_group['description'] += 'p'
        result = roles_group_client.update(roles_group, result.content['name'])
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        result = roles_group_client.delete('TestRolesGroup')
        self.assertTrue(result.response.status == 204)
        time.sleep(1)

        # Tests Cleanup

        result = role_client.delete('TestRole')
        self.assertTrue(result.response.status == 204)
        time.sleep(1)

        result = feature_client.delete('TestFeature')
        self.assertTrue(result.response.status == 204)
        time.sleep(1)

        result = resource_client.delete(resource_id)
        self.assertTrue(result.response.status == 204)
        time.sleep(1)


if __name__ == '__main__':
    unittest.main()



from alas_ce0.common.client_base import ApiClientBase


class NotificationClient(ApiClientBase):
    entity_endpoint_base_url = '/management/notifications/'

    def notify_user(self, resource_name, params=None):
        if params is None:
            params = dict()

        return self.http_post_json(self.entity_endpoint_base_url + 'user/' + resource_name, params)


# coding=utf-8
import time
import unittest

from alas_ce0.management.contact import ContactClient

from alas_ce0.management.packaging import PackagingLocationClient

from config import API_ACCESS_CONFIG


class TestPackagingLocationApi(unittest.TestCase):
    def test_crud(self):
        # Tests Setup

        contact_client = ContactClient(**API_ACCESS_CONFIG)
        contact = {
            'code': '44444444-4',
            'first_name': 'Contact FirstName',
            'last_name': 'Contact LastName',
            'land_line': '221345678',
            'mobile_phone': '921345678',
            'email': 'contact@gmail.com',
            'web': 'http://www.contact.com'
        }

        result = contact_client.create(contact)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        # PackagingLocation Tests

        packaging_location_client = PackagingLocationClient(**API_ACCESS_CONFIG)
        packaging_location = {
            "code": "Directv-Fijo-Test",
            "type": 1,
            "location": {
                "country_code": "CL",
                "zone_type": 1,
                "geo_coding": "Avenida Vitacura 4380, Vitacura, Chile",
                "geo_location": {
                    "lat": -33.398823,
                    "lon": -70.588274
                },
                "what3words": "liner.cooking.montage",
                "reference": "En la esquina de Vitacura con Américo Vespucio",
                "structure_id": 13132,
                "sector": "",
                "street": "Vitacura",
                "number": "4380",
            },
            "contact": "44444444-4",
        }

        result = packaging_location_client.create(packaging_location)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        result = packaging_location_client.get_by_id(result.content['code'])
        self.assertTrue(result.response.status == 200 and result.content)

        result = packaging_location_client.get_by_id('sample-packaging')
        self.assertTrue(result.response.status == 404)

        result = packaging_location_client.search({'what3words': 'liner.cooking.montage'})
        self.assertTrue(result.response.status == 200 and result.content)

        result = packaging_location_client.delete("Directv-Fijo-Test")
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)

        result = packaging_location_client.create(packaging_location)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        packaging_location['type'] = 2
        result = packaging_location_client.update(packaging_location, result.content['code'])
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        result = packaging_location_client.delete("Directv-Fijo-Test")
        self.assertTrue(result.response.status == 204)
        time.sleep(1)

        # Tests Cleanup

        result = contact_client.delete('44444444-4')
        self.assertTrue(result.response.status == 204)
        time.sleep(1)


if __name__ == '__main__':
    unittest.main()



import unittest

from alas_ce0.management.task import TaskClient

from config import API_ACCESS_CONFIG


class TestTaskClient(unittest.TestCase):
    def test_queue(self):
        task_client = TaskClient(**API_ACCESS_CONFIG)

        result = task_client.enqueue('delivery-order')
        self.assertTrue(result.response.status == 200)

if __name__ == '__main__':
    unittest.main()



# coding=utf-8
import unittest

import time
from alas_ce0.management.shelf import ShelfCellTemplateClient

from config import API_ACCESS_CONFIG


class TestShelfCellApi(unittest.TestCase):
    def test_crud(self):
        # ShelfCell Tests

        shelf_cell_template_client = ShelfCellTemplateClient(**API_ACCESS_CONFIG)
        shelf_cell_template = {
            'volume': {
                'width': 50.25,
                'height': 60.13,
                'depth': 25.34
            }
        }

        result = shelf_cell_template_client.create(shelf_cell_template)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)
        shelf_cell_code = result.content['code']

        result = shelf_cell_template_client.get_by_id(result.content['code'])
        self.assertTrue(result.response.status == 200 and result.content)

        result = shelf_cell_template_client.search({'code': result.content['code']})
        self.assertTrue(result.response.status == 200 and result.content)

        shelf_cell_template_code = result.content['items'][0]['code']
        result = shelf_cell_template_client.get_by_id('sample-shelf-cell')
        self.assertTrue(result.response.status == 404)

        result = shelf_cell_template_client.delete(shelf_cell_template_code)
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)

        result = shelf_cell_template_client.create(shelf_cell_template)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        shelf_cell_template['volume'] = {
            'width': 51.25,
            'height': 61.13,
            'depth': 22.34
        }

        result = shelf_cell_template_client.update(shelf_cell_template, result.content['code'])
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        result = shelf_cell_template_client.delete(shelf_cell_code)
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)


if __name__ == '__main__':
    unittest.main()



import base64

from alas_ce0.common.client_base import ApiClientBase


class ConfigurationClient(ApiClientBase):
    entity_endpoint_base_url = '/management/configurations/'

    def set(self, config_name, content):
        params = {
            'file_name': config_name,
            'base64_content': base64.encodestring(content)
        }
        return self.http_post_json(self.entity_endpoint_base_url + '_set', params)

    def get(self, config_name):
        return self.http_get(self.entity_endpoint_base_url + config_name)


from enum import Enum

from alas_ce0.management.task import TaskClient

from alas_ce0.common.client_base import EntityClientBase


class RouteStatusType(Enum):
    Created = 1
    Validating = 2
    Validated = 3
    InRoute = 4
    Finished = 5


class RouteSegmentStatusType(Enum):
    Created = 1
    NotValidated = 2
    Validated = 3
    Traveling = 4
    NotDelivered = 5
    Delivered = 6


class RouteClient(EntityClientBase):
    entity_endpoint_base_url = '/scheduling/routes/'

    def __init__(self, country_code='cl', **kwargs):
        super(RouteClient, self).__init__(**kwargs)
        self.entity_endpoint_base_url += country_code + '/'

    def create_from_orders(self, params, async=True):
        if async:
            return TaskClient(**self.args).enqueue('route-create', params)
        else:
            return self.http_post_json(self.entity_endpoint_base_url + "_create-from-orders", params)

    def upload_file(self, user_name, sender_code, base64_content, file_format="txt", description=None):
        params = {
            'user_name': user_name,
            'sender_code': sender_code,
            'base64_content': base64_content,
            'format': file_format,
            'description': description,
        }
        return self.http_post_json(self.entity_endpoint_base_url + "_upload-file", params)

    def change_status_route_segment(self, id, params):
        return self.http_post_json(
            self.entity_endpoint_base_url + "{0}/_change-status-route-segment".format(id), params
        )

    def reject_route_segment(self, id, params):
        return self.http_post_json(
            self.entity_endpoint_base_url + "{0}/_reject-route-segment".format(id), params
        )

    def approve_route(self, id, params):
        return self.http_post_json(
            self.entity_endpoint_base_url + "{0}/_approve-route".format(id), params
        )

    def delete_route(self, id, params):
        return self.http_post_json(
            self.entity_endpoint_base_url + "{0}/_delete-route".format(id), params
        )

    def update_route_segments(self, id, params):
        return self.http_post_json(
            self.entity_endpoint_base_url + "{0}/_update-route-segments".format(id), params
        )
